#ifndef NT2_INCLUDE_FUNCTIONS_EXPONENT_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_EXPONENT_HPP_INCLUDED

#include <nt2/ieee/include/functions/exponent.hpp>

#endif
